@@ -6,7 +6,7 @@ use 5.008_001;
 
 use App::Memcached::CLI::Util ':all';
 
-use version; our $VERSION = 'v0.5.0';
+use version; our $VERSION = 'v0.5.1';
 
 my $DISPLAY_DATA_LENGTH = 320;
 
@@ -43,6 +43,13 @@ sub save {
     return $ret;
 }
 
+sub remove {
+    my $self = shift;
+    my $ds   = shift;
+    my $ret  = $ds->delete($self->{key});
+    return $ret;
+}
+
 sub output {
     my $self = shift;
     my $space = q{ } x 4;
