@@ -16,7 +16,7 @@ use App::Memcached::CLI::DataSource;
 use App::Memcached::CLI::Item;
 use App::Memcached::CLI::Util ':all';
 
-use version; our $VERSION = 'v0.5.0';
+use version; our $VERSION = 'v0.5.1';
 
 my $PROGRAM = basename $0;
 
@@ -31,6 +31,7 @@ my %COMMAND2ALIASES = (
     detail     => [],
     get        => [],
     set        => [],
+    delete     => [],
 );
 my %COMMAND_OF;
 while (my ($cmd, $aliases) = each %COMMAND2ALIASES) {
@@ -233,6 +234,14 @@ Usage:
     > set mykey1 MyValue1
     > set mykey2 MyValue2 0     # Never expires. Default
     > set mykey3 MyValue3 120 1
+EODESC
+        },
+        +{
+            command => 'delete',
+            summary => 'Delete data of KEY',
+            description => <<'EODESC',
+Usage:
+    > delete <KEY>
 EODESC
         },
     );
@@ -316,6 +325,22 @@ sub set {
     return 1;
 }
 
+sub delete {
+    my $self = shift;
+    my $key  = shift;
+    unless ($key) {
+        print "No KEY specified.\n";
+        return;
+    }
+    my $item = App::Memcached::CLI::Item->new(key => $key);
+    unless ($item->remove($self->{ds})) {
+        warn "Failed to delete item. KEY $key";
+        return;
+    }
+    print "OK\n";
+    return 1;
+}
+
 sub cachedump {
     my $self  = shift;
     my $class = shift;
